Array256

Struct Array256 

pub struct Array256<S> { /* private fields */ }
A sparse array of 256 elements.

Indexed by Bitset256 and backed by a configurable ArrayStorage, which is a contiguous chunk of memory holding up to 256 values.

Implementations

Source

impl<S> Array256<S>

pub const EMPTY: Self

The empty array.

Source

impl<S> Array256<S>
where S: ArrayStorage,

pub fn test(&self, index: u8) -> bool

Check if the specified index is occupied.

pub fn intersects(&self, other: &Bitset256) -> bool

Check whether this array’s occupancy intersects with the given bitset.

pub fn intersection_top(&self, other: &Bitset256) -> Option<u8>

Check whether this array’s occupancy intersects with the given bitset, and if so, the highest set bit of that intersection.

pub const fn is_empty(&self) -> bool

Return whether this array has no elements.

pub fn len(&self) -> usize
where S: AsRef<[S::T]>,

Get the number of items in this array.

pub fn get(&self, index: u8) -> Option<&S::T>
where S: AsRef<[S::T]>,

Get a reference to the element at the specified index, if there is one.

pub fn get_mut(&mut self, index: u8) -> Option<&mut S::T>
where S: AsMut<[S::T]>,

Get a mutable reference to the element at the specified index, if there is one.

pub fn insert(&mut self, index: u8, element: S::T) -> Option<S::T>
where S: AsMut<[S::T]>,

Insert an item at the specified index. Returns the previous occupant if there was one.

pub fn remove(&mut self, index: u8) -> Option<S::T>
where S: AsRef<[S::T]>,

Remove an item by index.

pub fn clear(&mut self)

Clear the array.

pub const fn bitset(&self) -> &Bitset256

Get a reference to the internal Bitset256 which stores the occupied storage indices.

pub fn iter(&self) -> impl Iterator<Item = (u8, &S::T)>
where S: AsRef<[S::T]>,

Iterate over all occupied entries in the array.

pub fn iter_after(&self, n: u8) -> impl Iterator<Item = (u8, &S::T)>
where S: AsRef<[S::T]>,

Iterate over occupied entries in the array starting after index n.

pub fn iter_mut(&mut self) -> impl Iterator<Item = (u8, &mut S::T)>
where S: AsMut<[S::T]>,

Iterate over mutable references to all occupied entries in the array.

pub fn custom_storage_fmt<'slf, 'f, U>( &'slf self, f: &'f dyn Fn(&'slf S::T) -> U, ) -> impl Debug + 'slf
where U: Debug + 'slf, S: AsRef<[S::T]>, 'f: 'slf,

Provide a Debug instance for this value when T is not necessarily Debug.

pub fn clone_with(&self, f: &dyn Fn(&S::T) -> S::T) -> Self
where S: FromIterator<S::T> + AsRef<[S::T]>,

Clone self with a custom function supporting clone of &T.